@@ -475,6 +475,9 @@ class SetAttributeAccessor:
     def remove(self, item):
         self.mapping.remove(self._attribute.serialize(item))
 
+    def __eq__(self, other):
+        return set(self) == other
+
     def __and__(self, item):
         return set(item) & set(self)
 
@@ -539,6 +542,8 @@ class SetAttribute(sheraf.attributes.simples.TypedAttribute):
         self.persistent_type = persistent_type
         self.accessor_type = accessor_type
         kwargs.setdefault("default", self.persistent_type)
+        kwargs["read_memoization"] = False
+        kwargs["write_memoization"] = False
         super().__init__(**kwargs)
 
     def values(self, set_):
@@ -609,11 +614,11 @@ class SetAttribute(sheraf.attributes.simples.TypedAttribute):
         replacement=False,
     ):
         if addition:
-            for item in new_value & (new_value ^ old_value):
+            for item in set(new_value) & (set(new_value) ^ old_value):
                 old_value.add(item)
 
         if deletion:
-            for item in old_value & (old_value ^ new_value):
+            for item in old_value & (old_value ^ set(new_value)):
                 old_value.remove(item)
 
         return old_value
