@@ -101,6 +101,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
 
     def __init__(self, *args, **kwargs):
         self._identifier = None
+        self._raw_identifier = None
 
         if not self.primary_key():
             raise sheraf.exceptions.PrimaryKeyException(
@@ -440,7 +441,9 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
         yield_callbacks = []
         attribute = self.attributes.get(name)
 
-        if attribute:
+        if attribute and (
+            attribute.indexes or attribute.cb_creation or attribute.cb_edition
+        ):
             was_created = attribute.is_created(self)
             if not was_created:
                 prev_value = None
@@ -454,6 +457,11 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
                         yield_callbacks.append(res)
 
             else:
+                if any(index.primary for index in attribute.indexes.values()):
+                    raise sheraf.SherafException(
+                        f"Attribute {name} has a primary index and cannot be edited."
+                    )
+
                 prev_value = getattr(self, name)
                 for callback in attribute.cb_edition:
                     res = callback(self, value, prev_value)
@@ -468,7 +476,9 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
 
         super().__setattr__(name, value)
 
-        if attribute:
+        if attribute and (
+            attribute.indexes or attribute.cb_creation or attribute.cb_edition
+        ):
             try:
                 self.after_index_edition(attribute, old_values)
             except sheraf.SherafException:
@@ -550,6 +560,16 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
 
         return self._identifier
 
+    @property
+    def raw_identifier(self):
+        if not self._identifier:
+            self._identifier = getattr(self, self.primary_key())
+
+        if not self._raw_identifier:
+            self._raw_identifier = self.mapping[self.primary_key()]
+
+        return self._raw_identifier
+
     def _is_indexable(self, index):
         """
         To have its entries updated, an index must have its table previously
@@ -683,7 +703,11 @@ class IndexedModel(BaseIndexedModel, metaclass=IndexedModelMetaclass):
 
     @classmethod
     def index_manager(cls, index=None):
-        return MultipleDatabaseIndexManager(cls.database_name, cls.table, index)
+        return MultipleDatabaseIndexManager(
+            cls.database_name,
+            cls.table,
+            index,
+        )
 
     def __init__(self, *args, **kwargs):
         if "id" not in self.__class__.attributes:
